@@ -10,6 +10,9 @@ depends() {
 }
 
 install() {
+    # Force inclusion of needed binaries
+    inst_multiple basename mkdir mount
+
     # Install the hook into the 'pre-pivot' stage
     inst_hook pre-pivot 99 "$moddir/mount-layers.sh"
 }
