@@ -1,7 +1,10 @@
 #!/bin/sh
 # Path where Dracut mounts the ISO
+
+command -v getarg > /dev/null || . /lib/dracut-lib.sh
+
 ISO_PATH="/run/initramfs/live/kdeos/x86_64"
-LAYERS_ROOT="/tmp/kaos_layers"
+LAYERS_ROOT="/run/kaos/layers"
 LOWERDIR=""
 
 # 1. Find and mount all .sqfs files except the main root (already mounted at $NEWROOT)
